# disnake-ext-invitetracker

[![PyPI version info](https://img.shields.io/pypi/v/disnake-ext-invitetracker.svg)](https://pypi.python.org/pypi/disnake-ext-invitetracker)

## About

A module that allows you to track invitations

## Installation

**Python 3.8 or higher is required**

It is necessary to first install [Disnake](https://github.com/DisnakeDev/disnake)

Then install the extension by running one of the following commands:

```py 
# Linux/macOS
python3 -m pip install -U disnake-ext-invitetracker

# Windows
py -3 -m pip install -U disnake-ext-invitetracker
```

## Links

- [Usage Examples](https://github.com/earluv/disnake-ext-invitetracker/tree/main/examples)
- [Disnake Server](https://discord.gg/disnake)
- [Disnake [RU] Server](https://discord.gg/RrpKVNuRCc)
- [Earluv | Discord](https://discordapp.com/users/211148434273468426)

## License

Copyright (c) 2024 earluv